BlockCount

Struct BlockCount 

pub struct BlockCount(pub u32);
The a number of blocks (or sectors).

Add this to a BlockIdx to get an actual address on disk.

Tuple Fields

0: u32

Implementations

Source

impl BlockCount

pub const fn from_bytes(byte_count: u32) -> BlockCount

How many blocks are required to hold this many bytes.

assert_eq!(BlockCount::from_bytes(511), BlockCount(1));
assert_eq!(BlockCount::from_bytes(512), BlockCount(1));
assert_eq!(BlockCount::from_bytes(513), BlockCount(2));
assert_eq!(BlockCount::from_bytes(1024), BlockCount(2));
assert_eq!(BlockCount::from_bytes(1025), BlockCount(3));
pub fn offset_bytes(self, offset: u32) -> BlockCount

Take a number of blocks and increment by the integer number of blocks required to get to the block that holds the byte at the given offset.