Error

Enum Error 

pub enum Error<E>
where E: Error,
{
Show 30 variants DeviceError(E), FormatError(&'static str), NoSuchVolume, FilenameError(FilenameError), TooManyOpenVolumes, TooManyOpenDirs, TooManyOpenFiles, BadHandle, NotFound, FileAlreadyOpen, DirAlreadyOpen, OpenedDirAsFile, OpenedFileAsDir, DeleteNonEmptyDir, VolumeStillInUse, VolumeAlreadyOpen, Unsupported, EndOfFile, BadCluster, ConversionError, NotEnoughSpace, AllocationError, UnterminatedFatChain, ReadOnly, FileAlreadyExists, BadBlockSize(u16), InvalidOffset, DiskFull, DirAlreadyExists, LockError,
}
All the ways the functions in this crate can fail.

Variants



DeviceError(E)

The underlying block device threw an error.



FormatError(&'static str)

The filesystem is badly formatted (or this code is buggy).



NoSuchVolume

The given VolumeIdx was bad,



FilenameError(FilenameError)

The given filename was bad



TooManyOpenVolumes

Out of memory opening volumes



TooManyOpenDirs

Out of memory opening directories



TooManyOpenFiles

Out of memory opening files



BadHandle

Bad handle given



NotFound

That file or directory doesn’t exist



FileAlreadyOpen

You can’t open a file twice or delete an open file



DirAlreadyOpen

You can’t open a directory twice



OpenedDirAsFile

You can’t open a directory as a file



OpenedFileAsDir

You can’t open a file as a directory



DeleteNonEmptyDir

You can’t delete a non-empty directory



VolumeStillInUse

You can’t close a volume with open files or directories



VolumeAlreadyOpen

You can’t open a volume twice



Unsupported

We can’t do that yet



EndOfFile

Tried to read beyond end of file



BadCluster

Found a bad cluster



ConversionError

Error while converting types



NotEnoughSpace

The device does not have enough space for the operation



AllocationError

Cluster was not properly allocated by the library



UnterminatedFatChain

Jumped to free space during FAT traversing



ReadOnly

Tried to open Read-Only file with write mode



FileAlreadyExists

Tried to create an existing file



BadBlockSize(u16)

Bad block size - only 512 byte blocks supported



InvalidOffset

Bad offset given when seeking



DiskFull

Disk is full



DirAlreadyExists

A directory with that name already exists



LockError

The filesystem tried to gain a lock whilst already locked.

This is either a bug in the filesystem, or you tried to access the filesystem API from inside a directory iterator (that isn’t allowed).