[−][src]Enum embedded_sdmmc::FilenameError
Various filename related errors that can occur.
Variants
InvalidCharacterTried to create a file with an invalid character.
FilenameEmptyTried to create a file with no file name.
NameTooLongGiven name was too long (we are limited to 8.3).
MisplacedPeriodCan't start a file with a period, or after 8 characters.