[−][src]Enum embedded_sdmmc::Mode
The different ways we can open a file.
Variants
ReadOnlyOpen a file for reading, if it exists.
ReadWriteAppendOpen a file for appending (writing to the end of the existing file), if it exists.
ReadWriteTruncateOpen a file and remove all contents, before writing to the start of the existing file, if it exists.
ReadWriteCreateCreate a new empty file. Fail if it exists.
ReadWriteCreateOrTruncateCreate a new empty file, or truncate an existing file.
ReadWriteCreateOrAppendCreate a new empty file, or append to an existing file.