[−][src]Enum embedded_sdmmc::SdMmcError
The possible errors SdMmcSpi can generate.
Variants
TransportWe got an error from the SPI peripheral
CantEnableCRCWe failed to enable CRC checking on the SD card
TimeoutReadBufferWe didn't get a response when reading data from the card
TimeoutWaitNotBusyWe didn't get a response when waiting for the card to not be busy
TimeoutCommand(u8)We didn't get a response when executing this command
TimeoutACommand(u8)We didn't get a response when executing this application-specific command
Cmd58ErrorWe got a bad response from Command 58
RegisterReadErrorWe failed to read the Card Specific Data register
CrcError(u16, u16)We got a CRC mismatch (card gave us, we calculated)
ReadErrorError reading from the card
WriteErrorError writing to the card
BadStateCan't perform this operation with the card in this state
CardNotFoundCouldn't find the card