[−][src]Struct embedded_sdmmc::Block
Represents a standard 512 byte block (also known as a sector). IBM PC formatted 5.25" and 3.5" floppy disks, SD/MMC cards up to 1 GiB in size and IDE/SATA Hard Drives up to about 2 TiB all have 512 byte blocks.
This library does not support devices with a block size other than 512 bytes.
Fields
contents: [u8; 512]The 512 bytes in this block (or sector).
Methods
impl Block[src]
pub const LEN: usize[src]
All our blocks are a fixed length of 512 bytes. We do not support 'Advanced Format' Hard Drives with 4 KiB blocks, nor weird old pre-3.5-inch floppy disk formats.
pub const LEN_U32: u32[src]
Sometimes we want LEN as a u32 and the casts don't look nice.
pub fn new() -> Block[src]
Create a new block full of zeros.