File

Struct File 

pub struct File<'a, D, T, const MAX_DIRS: usize, const MAX_FILES: usize, const MAX_VOLUMES: usize>
where D: BlockDevice, T: TimeSource,
{ /* private fields */ }
A handle for an open file on disk, which closes on drop.

In contrast to a RawFile, a File holds a mutable reference to its parent VolumeManager, which restricts which operations you can perform.

If you drop a value of this type, it closes the file automatically, but any error that may occur will be ignored. To handle potential errors, use the File::close method.

Implementations

Source

impl<'a, D, T, const MAX_DIRS: usize, const MAX_FILES: usize, const MAX_VOLUMES: usize> File<'a, D, T, MAX_DIRS, MAX_FILES, MAX_VOLUMES>
where D: BlockDevice, T: TimeSource,

pub fn new( raw_file: RawFile, volume_mgr: &'a VolumeManager<D, T, MAX_DIRS, MAX_FILES, MAX_VOLUMES>, ) -> Self

Create a new File from a RawFile

pub fn read(&self, buffer: &mut [u8]) -> Result<usize, Error<D::Error>>

Read from the file

Returns how many bytes were read, or an error.

See VolumeManager::read for details, except the file given is this file.

pub fn write(&self, buffer: &[u8]) -> Result<(), Error<D::Error>>

Write to the file

See VolumeManager::write for details, except the file given is this file.

pub fn is_eof(&self) -> bool

Check if a file is at End Of File.

See VolumeManager::file_eof for details, except the file given is this file.

pub fn seek_from_current(&self, offset: i32) -> Result<(), Error<D::Error>>

Seek a file with an offset from the current position.

See VolumeManager::file_seek_from_current for details, except the file given is this file.

pub fn seek_from_start(&self, offset: u32) -> Result<(), Error<D::Error>>

Seek a file with an offset from the start of the file.

See VolumeManager::file_seek_from_start for details, except the file given is this file.

pub fn seek_from_end(&self, offset: u32) -> Result<(), Error<D::Error>>

Seek a file with an offset back from the end of the file.

See VolumeManager::file_seek_from_end for details, except the file given is this file.

pub fn length(&self) -> u32

Get the length of a file

See VolumeManager::file_length for details, except the file given is this file.

pub fn offset(&self) -> u32

Get the current offset of a file

See VolumeManager::file_offset for details, except the file given is this file.

pub fn to_raw_file(self) -> RawFile

Convert back to a raw file

pub fn flush(&self) -> Result<(), Error<D::Error>>

Flush any written data by updating the directory entry.

See VolumeManager::flush_file for details, except the file given is this file.

pub fn close(self) -> Result<(), Error<D::Error>>

Consume the File handle and close it. The behavior of this is similar to using core::mem::drop or letting the File go out of scope, except this lets the user handle any errors that may occur in the process, whereas when using drop, any errors will be discarded silently.