ShortFileName

Struct ShortFileName 

pub struct ShortFileName { /* private fields */ }
An MS-DOS 8.3 filename.

ISO-8859-1 encoding is assumed. All lower-case is converted to upper-case by default.

Implementations

Source

impl ShortFileName

pub const fn parent_dir() -> Self

Get a short file name containing “..”, which means “parent directory”.

pub const fn this_dir() -> Self

Get a short file name containing “.”, which means “this directory”.

pub fn base_name(&self) -> &[u8]

Get base name (without extension) of the file.

pub fn extension(&self) -> &[u8]

Get extension of the file (without base name).

pub fn create_from_str(name: &str) -> Result<ShortFileName, FilenameError>

Create a new MS-DOS 8.3 space-padded file name as stored in the directory entry.

The output uses ISO-8859-1 encoding.

pub unsafe fn to_volume_label(self) -> VolumeName

Convert a Short File Name to a Volume Label.

Safety

Volume Labels can contain things that Short File Names cannot, so only do this conversion if you have the name of a directory entry with the ‘Volume Label’ attribute.

pub fn csum(&self) -> u8

Get the LFN checksum for this short filename